@@ -11,10 +11,10 @@ import torch.nn.functional as F
 from PIL import Image
 from torch.cuda import amp
 
-from utils.datasets import letterbox
-from utils.general import increment_path, make_divisible, non_max_suppression, scale_coords, xyxy2xywh
-from utils.plots import color_list, plot_one_box
-from utils.torch_utils import copy_attr, time_synchronized
+from yolov7.utils.datasets import letterbox
+from yolov7.utils.general import increment_path, make_divisible, non_max_suppression, scale_coords, xyxy2xywh
+from yolov7.utils.plots import color_list, plot_one_box
+from yolov7.utils.torch_utils import copy_attr, time_synchronized
 
 ##### basic ####
 
@@ -891,6 +891,9 @@ class autoShape(nn.Module):
 
     def __init__(self, model):
         super(autoShape, self).__init__()
+        """
+        The copy_attr function was added by @kadirnar.
+        """
         copy_attr(self, model, include=("yaml", "nc", "hyp", "names", "stride", "abc"), exclude=())  # copy attributes
         self.model = model.eval()
 
@@ -2247,4 +2250,4 @@ class ST2CSPC(nn.Module):
         return self.cv4(torch.cat((y1, y2), dim=1))
 
 
-##### end of swin transformer v2 #####
+##### end of swin transformer v2 #####
\ No newline at end of file
